# Change log
Change log for [licins](https://github.com/dogoncouch/licins)

## [Unreleased]
### Fixed
- Fix bug with year

### Added
- Automatically append space to comments
- Append newline to hashbangs
- Python 3 compatibility

## [1.0] 04-01-2017
- First release
